# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account_move
from . import event_booth_registration
from . import event_booth
from . import event_booth_category
from . import event_type_booth
from . import product_product
from . import product_template
from . import sale_order
from . import sale_order_line
